@@ -8,7 +8,7 @@ import re
 class Youtube(Plugin):
     @classmethod
     def can_handle_url(self, url):
-        return "youtube.com" in url
+        return "youtube.com" in url or "youtu.be" in url
 
     @classmethod
     def stream_weight(cls, stream):
@@ -45,6 +45,13 @@ class Youtube(Plugin):
     def _get_stream_info(self, url):
         res = urlget(url)
         config = self._find_config(res.text)
+        
+        if not config:
+            watch_match = re.search("href=\"/(watch\?v=.+?)\"", res.text)
+            if watch_match:
+                watch_url = "http://youtube.com/%s" % watch_match.group(1)
+                res = urlget(watch_url)
+                config = self._find_config(res.text)
 
         if config:
             return parse_json(config, "config JSON")
