@@ -41,7 +41,7 @@ AAC_SEQUENCE_HEADER = 0x00
 AVC_SEQUENCE_HEADER = 0x00
 AVC_SEQUENCE_END = 0x02
 
-# Some streams hosted by Akamai seems to require a hdcore parameter
+# Some streams hosted by Akamai seem to require a hdcore parameter
 # to function properly.
 HDCORE_VERSION = "3.1.0"
 
@@ -442,7 +442,7 @@ class HDSStreamIO(IOBase):
         table = self.segmentruntable.payload.segment_run_entry_table
 
         for segment, start, end in self._iterate_segments(table):
-            if fragment >= start and fragment <= end:
+            if fragment >= (start + 1) and fragment <= (end + 1):
                 break
         else:
             segment = 1
@@ -594,7 +594,7 @@ class HDSStream(Stream):
     @classmethod
     def parse_manifest(cls, session, url, timeout=60, rsession=None,
                        pvswf=None):
-        """Parses a HDS manifest and returns it's substreams.
+        """Parses a HDS manifest and returns its substreams.
 
         :param url: The URL to the manifest.
         :param timeout: How long to wait for data to be returned from
@@ -615,9 +615,11 @@ class HDSStream(Stream):
 
         parsed = urlparse(url)
         baseurl = manifest.findtext("baseURL")
+        baseheight = manifest.findtext("height")
         bootstraps = {}
         streams = {}
 
+
         if not baseurl:
             baseurl = urljoin(url, os.path.dirname(parsed.path)) + "/"
 
@@ -663,8 +665,10 @@ class HDSStream(Stream):
                     quality = bitrate + "k"
                 elif streamid:
                     quality = streamid
+                elif baseheight:
+                    quality = baseheight + "p"
                 else:
-                    continue
+                    quality = "live"
 
                 metadata = media.findtext("metadata")
 
