@@ -174,6 +174,7 @@ def output_stream_http(plugin, streams):
         server.close(True)
 
     player.close()
+    server.close()
 
 
 def output_stream_passthrough(stream):
@@ -578,11 +579,6 @@ def setup_livestreamer():
 def setup_options():
     """Sets Livestreamer options."""
 
-    if args.gomtv_username and not args.gomtv_password:
-        gomtv_password = console.askpass("Enter GOMTV password: ")
-    else:
-        gomtv_password = args.gomtv_password
-
     livestreamer.set_option("errorlog", args.errorlog)
 
     if args.rtmpdump:
@@ -607,10 +603,6 @@ def setup_options():
         livestreamer.set_plugin_option("twitch", "cookie",
                                        args.jtv_cookie)
 
-    if args.jtv_legacy_names:
-        console.logger.warning("The option --jtv/twitch-legacy-names is "
-                               "deprecated since version 1.7.2.")
-
     if args.jtv_password:
         livestreamer.set_plugin_option("justintv", "password",
                                        args.jtv_password)
@@ -621,17 +613,42 @@ def setup_options():
         livestreamer.set_plugin_option("twitch", "oauth_token",
                                        args.twitch_oauth_token)
 
-    if args.gomtv_cookie:
-        livestreamer.set_plugin_option("gomtv", "cookie",
-                                       args.gomtv_cookie)
+    if args.ustream_password:
+        livestreamer.set_plugin_option("ustreamtv", "password",
+                                       args.ustream_password)
+
+    if args.crunchyroll_username:
+        livestreamer.set_plugin_option("crunchyroll", "username",
+                                       args.crunchyroll_username)
+
+    if args.crunchyroll_username and not args.crunchyroll_password:
+        crunchyroll_password = console.askpass("Enter Crunchyroll password: ")
+    else:
+        crunchyroll_password = args.crunchyroll_password
+
+    if crunchyroll_password:
+        livestreamer.set_plugin_option("crunchyroll", "password",
+                                       crunchyroll_password)
+    if args.crunchyroll_purge_credentials:
+        livestreamer.set_plugin_option("crunchyroll", "purge_credentials",
+                                       args.crunchyroll_purge_credentials)
+
+    # Deprecated options
+    if args.jtv_legacy_names:
+        console.logger.warning("The option --jtv/twitch-legacy-names is "
+                               "deprecated and will be removed in the future.")
 
     if args.gomtv_username:
-        livestreamer.set_plugin_option("gomtv", "username",
-                                       args.gomtv_username)
+        console.logger.warning("The option --gomtv-username is deprecated "
+                               "and will be removed in the future.")
 
-    if gomtv_password:
-        livestreamer.set_plugin_option("gomtv", "password",
-                                       gomtv_password)
+    if args.gomtv_password:
+        console.logger.warning("The option --gomtv-password is deprecated "
+                               "and will be removed in the future.")
+
+    if args.gomtv_cookie:
+        console.logger.warning("The option --gomtv-cookie is deprecated "
+                               "and will be removed in the future.")
 
 
 def check_root():
